##  Step 4: Configure Milestone Mapping (Optional)
Map key dates from Jira to custom milestones in SAP LeanIX to align project timelines across both systems.
**Note**
Milestones do not need to exist in SAP LeanIX beforehand—they'll be created automatically during sync
  1. Under Milestones, choose Add Milestone.
  2. Select a Jira date field.
For example, Start Date.
  3. Enter the name of the milestone to be created in SAP LeanIX.
For example, Project Start.
  4. Choose the sync direction.
For example, Jira to SAP LeanIX


Repeat this step for all milestones that you want to map.
